<?php

class TemplateBuilder
{
    private $_themeDir;
    private $_previewDir;

    public function __construct($themeDir)
    {
        $this->_themeDir = $themeDir;
        $this->_previewDir = $themeDir . _PREVIEW_SUFFIX_;
    }

    public function build($info, $content)
    {
        ProviderLog::start('TemplateBuilder::_buildTemplate');
        $result = $this->_buildTemplate($info, $content);
        ProviderLog::end('TemplateBuilder::_buildTemplate');
        return $result;
    }
   
    /**
     * Build theme layout files header.tpl, footer.tpl
     */
    private function _buildTemplate($info, $content)
    {
        $dir  = $info['dirname'];
        $name = $info['filename'];

        $content_before = $content;
        $content_after = '';
        $id = 'center_column';
        $searchable_content = '<div id="'.$id.'">{$HOOK_HOME}</div>';
        $position = strpos($content, $searchable_content);
        if ($position !== FALSE)
        {
            $content_before = substr($content, 0, $position) . '<div id="'.$id.'">';
            $content_after = '</div>'.substr($content, $position + strlen($searchable_content));
        }

        return $this->buildLayoutFiles($dir, '_'.$name, $content_before, $content_after);
    }
    
    public function buildLayoutFiles($dir, $name, $headerContent, $footerContent)
    {
        $headerPath = $dir . '/header' . $name . '.tpl';
        $footerPath = $dir . '/footer' . $name . '.tpl';
        FilesHelper::writeFile($headerPath, $headerContent);
        FilesHelper::writeFile($footerPath, $footerContent);
        
        return array($headerPath, $footerPath);
    }
}